@@ -1,25 +1,19 @@
 # global definitions
 # any character with XXX will be replaced by user input
 # has to match the values (characters) in the templates in the settings.R, the zzz.R file and the uniset_globals.R file
-glob_unisetEnvName <- "XXX_unisetEnv" 						# the character to be replaced in the template # the idea is that every package has its own environment with the same name for variables in that
 glob_targetPackageName <- "XXX_packageName"					#
 glob_targetPackageSettingsHomeVarName <- "XXX_SH"			#
-glob_targetPackageEnvName <- "XXX_targetEnv" 				# the short one like '.ap2'
 glob_targetPackgae_settingsObjectName <- "XXX_obj"			# like the 'stn' for ap2
 glob_targetPackage_templateSuffix <- "XXX_template"			#
 glob_settingsHomeSuffix <- "_SH"
 glob_actualSettingsName <- "XXX_actualSettingsName"			# for the header in the settings file
 glob_setupFuncName <- "XXX_setupFuncName"
 ####
-glob_filenameZZZ <- "zzz.R"
 glob_filenameGlobals <- "uniset_globals.R"
 glob_filnameSettings <- "settings.R"
 glob_filenameFunctions <- "uniset_functions.R"
 glob_folderPrev <- "UnisetFiles_R-pkg_'"
-glob_unisetEnvSuffix <- "_unisetEnv"
 ####
 glob_templGlobals <- "uniset_globals.R"
-glob_templZZZ <- "zzz.R"
 glob_templSettinsg <- "settings.R"
 ####
-glob_taPaEnvSuffix <- "_settingsEnv" # the suffix for the environment holding the settings. Will have the package name in front of it.
